@@ -288,26 +288,56 @@ class FeedConfig(BaseModel):
         return cls(**model.model_dump())
 
 
+class QuestionConfig(BaseModel):
+    id: Optional[UUID] = None
+    created_at: Optional[datetime] = None
+    updated_at: Optional[datetime] = None
+    organization: Optional[UUID] = None
+
+    questionnaire_id: Optional[UUID] = None
+    question_category: QuestionCategory
+    key: str
+    question: Optional[str] = None
+    text: Optional[str] = None
+    type: str
+    required: bool
+    options: Optional[list] = []
+
+    @classmethod
+    async def from_model(cls: "QuestionConfig", model: QuestionModel) -> "QuestionConfig":
+        return cls(**model.model_dump())
+
+
 class QuestionnaireConfig(BaseModel):
+    id: Optional[UUID] = None
+    created_at: Optional[datetime] = None
+    updated_at: Optional[datetime] = None
+    organization: Optional[UUID] = None
+
+    name: str
+    questions: list[QuestionConfig]
+
+    @classmethod
+    async def from_model(cls: "QuestionnaireConfig", model: QuestionnaireModel, questions: list[QuestionModel]) -> "QuestionnaireConfig":
+        return cls(
+            id=model.id,
+            created_at=model.created_at,
+            updated_at=model.updated_at,
+            organization=model.organization,
+            name=model.name,
+            questions=questions
+        )
+
+
+class QuestionnaireInfo(BaseModel):
     id: UUID
     created_at: datetime
     updated_at: Optional[datetime]
     organization: UUID
 
     name: str
-    questions: list[QuestionConfig]
-
-
-class QuestionConfig(BaseModel):
-    questionnaire_id: UUID
-    question_category: QuestionCategory
-    key: str
-    label: Optional[str]
-    text: Optional[str]
-    type: str
-    required: bool
-    options: Optional[list]
+    question_count: int
 
     @classmethod
-    async def from_model(cls: "QuestionnaireConfig", model: QuestionnaireModel) -> "QuestionnaireConfig":
-        return cls(**model.model_dump())
+    async def from_model(cls: "QuestionnaireInfo", model: QuestionnaireModel) -> "QuestionnaireInfo":
+        return cls(**model.model_dump())
\ No newline at end of file
