@@ -5,7 +5,7 @@ from datetime import datetime
 from typing import Optional, List
 
 from sqlalchemy import Column, JSON, UniqueConstraint, Enum
-from sqlmodel import Field
+from sqlmodel import Field, Relationship
 
 from ..general.models import BaseModel
 
@@ -100,13 +100,14 @@ class Vacancy(VacanciesOrganizationModel, table=True):
 
 class Questionnaire(VacanciesOrganizationModel, table=True):
     name: str = Field(index=True)
-
+    question_count: int = Field(default=0)
+    questions: list["Question"] = Relationship(back_populates="questionnaire", cascade_delete=True)
 
 class Question(VacanciesOrganizationModel, table=True):
-    questionnaire_id: UUID = Field(index=True)
+    questionnaire_id: UUID = Field(foreign_key="questionnaire.id", ondelete="CASCADE", index=True)
     question_category: QuestionCategory = Field(sa_column=Column(Enum(QuestionCategory)))
     key: str = Field(index=True)
-    label: Optional[str] = Field()
+    question: Optional[str] = Field()
     text: Optional[str] = Field()
     type: str = Field()
     required: bool = Field()
